
DL1a=> Production for the dec_3476 line and high NSB conditions,
with cleaning levels (14, 7)

Command:

lstmcpipe_generate_config PathConfigAllSkyFullDL1ab --dec_list dec_3476 --prod_id 20240229_dec34_nsb14 --kwargs source_prod_id=20240131_allsky_v0.10.5_all_dec_base

Then I modified in the yaml file the versions of lstchain and lstmcpipe to 
be used
